@@ -38,6 +38,7 @@
 #include <QDebug>
 #include <QTimer>
 #include <QStandardPaths>
+#include <QFile>
 
 #include <PackageKit/Transaction>
 #include <PackageKit/Daemon>
@@ -80,15 +81,6 @@ PackageKitBackend::PackageKitBackend(QObject* parent)
 
     SourcesModel::global()->addSourcesBackend(new PackageKitSourcesBackend(this));
 
-    QTimer::singleShot(0, this, &PackageKitBackend::delayedInit);
-}
-
-PackageKitBackend::~PackageKitBackend()
-{
-}
-
-void PackageKitBackend::delayedInit()
-{
     QString error;
     const bool b = m_appdata.load(&error);
     reloadPackageList();
@@ -102,6 +94,8 @@ void PackageKitBackend::delayedInit()
     }
 }
 
+PackageKitBackend::~PackageKitBackend() = default;
+
 bool PackageKitBackend::isFetching() const
 {
     return m_isFetching;
@@ -304,11 +298,11 @@ void PackageKitBackend::packageDetails(const PackageKit::Details& details)
 
 QSet<AbstractResource*> PackageKitBackend::resourcesByPackageName(const QString& name) const
 {
-    return resourcesByPackageNames<QSet<AbstractResource*>>({name});
+    return resourcesByPackageNames<QSet<AbstractResource*>, QVector<QString>>({name});
 }
 
-template <typename T>
-T PackageKitBackend::resourcesByPackageNames(const QStringList &pkgnames) const
+template <typename T, typename Q>
+T PackageKitBackend::resourcesByPackageNames(const Q &pkgnames) const
 {
     T ret;
     ret.reserve(pkgnames.size());
@@ -373,7 +367,7 @@ ResultsStream* PackageKitBackend::search(const AbstractResourcesBackend::Filters
             if (status == PackageKit::Transaction::Exit::ExitSuccess) {
                 const auto packageId = stream->property("packageId");
                 if (!packageId.isNull()) {
-                    const auto res = resourcesByPackageNames<QVector<AbstractResource*>>({PackageKit::Daemon::packageName(packageId.toString())});
+                    const auto res = resourcesByPackageNames<QVector<AbstractResource*>, QVector<QString>>({PackageKit::Daemon::packageName(packageId.toString())});
                     stream->resourcesFound(kFilter<QVector<AbstractResource*>>(res, [ids](AbstractResource* res){ return !ids.contains(res->appstreamId()); }));
                 }
             }
@@ -387,10 +381,17 @@ ResultsStream * PackageKitBackend::findResourceByPackageName(const QUrl& url)
 {
     AbstractResource* pkg = nullptr;
     if (url.scheme() == QLatin1String("appstream")) {
-        if (url.host().isEmpty())
+        const auto host = url.host();
+        if (host.isEmpty())
             passiveMessage(i18n("Malformed appstream url '%1'", url.toDisplayString()));
-        else
-            pkg = m_packages.packages.value(url.host());
+        else {
+            for (auto it = m_packages.packages.constBegin(), itEnd = m_packages.packages.constEnd(); it != itEnd; ++it) {
+                if (it.key().compare(host, Qt::CaseInsensitive) == 0) {
+                    pkg = it.value();
+                    break;
+                }
+            }
+        }
     }
     return new ResultsStream(QStringLiteral("PackageKitStream-url"), pkg ? QVector<AbstractResource*>{pkg} : QVector<AbstractResource*>{});
 }
@@ -402,7 +403,7 @@ bool PackageKitBackend::hasSecurityUpdates() const
 
 int PackageKitBackend::updatesCount() const
 {
-    return m_updatesPackageId.count();
+    return upgradeablePackages().count();
 }
 
 Transaction* PackageKitBackend::installApplication(AbstractResource* app, const AddonList& addons)
@@ -521,9 +522,29 @@ void PackageKitBackend::fetchDetails(const QString& pkgid)
 void PackageKitBackend::performDetailsFetch()
 {
     Q_ASSERT(!m_packageNamesToFetchDetails.isEmpty());
-    PackageKit::Transaction* transaction = PackageKit::Daemon::getDetails(m_packageNamesToFetchDetails.toList());
+    const auto ids = m_packageNamesToFetchDetails.toList();
+
+    PackageKit::Transaction* transaction = PackageKit::Daemon::getDetails(ids);
     connect(transaction, &PackageKit::Transaction::details, this, &PackageKitBackend::packageDetails);
     connect(transaction, &PackageKit::Transaction::errorCode, this, &PackageKitBackend::transactionError);
+
+    QSharedPointer<QMap<QString, int>> packageDependencies(new QMap<QString, int>);
+    auto trans = PackageKit::Daemon::dependsOn(ids);
+    connect(trans, &PackageKit::Transaction::errorCode, this, &PackageKitBackend::transactionError);
+    connect(trans, &PackageKit::Transaction::package, this, [packageDependencies](PackageKit::Transaction::Info /*info*/, const QString &packageID, const QString &/*summary*/) {
+        (*packageDependencies)[packageID] += 1;
+    });
+    connect(trans, &PackageKit::Transaction::finished, this, [this, packageDependencies](PackageKit::Transaction::Exit /*status*/) {
+        auto pkgDeps = (*packageDependencies);
+
+        for (auto it = pkgDeps.constBegin(), itEnd = pkgDeps.constEnd(); it != itEnd; ++it) {
+            const auto resources = resourcesByPackageName(PackageKit::Daemon::packageName(it.key()));
+            for(auto resource : resources) {
+                auto pkres = qobject_cast<PackageKitResource*>(resource);
+                pkres->setDependenciesCount(it.value());
+            }
+        }
+    });
 }
 
 void PackageKitBackend::checkDaemonRunning()
@@ -564,6 +585,25 @@ AbstractResource * PackageKitBackend::resourceForFile(const QUrl& file)
 
 static QString readDistroName()
 {
+    const QStringList osreleasenames = (QStringList() << QStringLiteral("/etc/os-release")
+                                                      << QStringLiteral("/usr/lib/os-release"));
+    foreach (QString osrelease, osreleasenames)
+    {
+        QFile file(osrelease);
+        if (file.open(QIODevice::ReadOnly | QIODevice::Text))
+        {
+            QByteArray line;
+            while (!file.atEnd()) {
+                line = file.readLine().trimmed();
+                if (line.startsWith("NAME=")) {
+                    auto output = line.right(line.length()-5);
+                    output = output.replace('\"',"");
+                    return QString::fromLocal8Bit(output);
+                }
+            }
+        }
+    }
+
     QProcess process;
     process.setEnvironment({QStringLiteral("LC_ALL=C")});
     process.start(QStringLiteral("lsb_release"), {QStringLiteral("-sd")});
