@@ -75,7 +75,8 @@ public:
         SectionRole,
         MimeTypes,
         SizeRole,
-        LongDescriptionRole
+        LongDescriptionRole,
+        AvailableVersionRole
     };
     Q_ENUM(Roles)
 
@@ -118,7 +119,7 @@ public:
     bool isBusy() const { return m_currentStream != nullptr; }
 
     bool lessThan(AbstractResource* rl, AbstractResource* rr) const;
-    void invalidateFilter();
+    Q_SCRIPTABLE void invalidateFilter();
     void invalidateSorting();
 
     void classBegin() override {}
